#
# spec file for package warp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _lto_cflags %{nil}
Name:           warp
Version:        0.8.0
Release:        1.2
Summary:        App to securely send files via the internet or local network
License:        GPL-3.0-or-later
URL:            https://apps.gnome.org/en-GB/app/app.drey.Warp/
Source0:        %{name}-%{version}.tar
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging
BuildRequires:  itstool
BuildRequires:  meson
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-bad-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(gtk4) >= 4.13.0
BuildRequires:  pkgconfig(libadwaita-1)
BuildRequires:  pkgconfig(zbar)
# Binary /usr/bin/warp conflicts with same name binary from totally different app ghc-wai-app-static
Conflicts:      ghc-wai-app-static

%description
Warp allows you to securely send files to each other via the internet or local
network by exchanging a word-based code.

The best transfer method will be determined using the "Magic Wormhole" protocol
which includes local network transfer if possible.

%lang_package

%prep
%autosetup -a1

%build
%meson
%meson_build

%install
%meson_install

%find_lang %{name} %{?no_lang_C}

%files
%license LICENSE
%doc README.md
%{_bindir}/warp
%{_datadir}/applications/*.desktop
%{_datadir}/help/C/%{name}/
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/metainfo/*.metainfo.xml
%dir %{_datadir}/warp
%{_datadir}/warp/licenses.json

%files lang -f %{name}.lang

%changelog
* Tue Oct 22 2024 Joshua Smith <smolsheep@opensuse.org>
- Current build requires manual intervention for vendoring.
  See gh/openSUSE-Rust/obs-service-cargo#106
- Remove redundant BuildRequires
- Update to version 0.8.0:
  * Better mobile support with bottom sheets and adaptive dialogs
  * Translation Updates
* Sun Mar 24 2024 Joshua Smith <smolsheep@opensuse.org>
- Added gstreamer/plugins & zbar to BuildRequires
- Update to version 0.7.0:
  * Add QR code scanning support via aperture, the library behind
    GNOME Camera
  * Port dialogs to AdwDialog
  * Translation Updates
* Mon Dec  4 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.6.2:
  * Fixes a potential security issue.
  * Minor design tweaks.
- Changes from version 0.6.1:
  * Fixes an issue where ZIP files would sometimes be corrupt after
    receiving.
- Changes from version 0.6.0:
  * Redesign code view with new QR code design.
  * Use new GNOME 45 design.
  * Add shortcuts to a few more buttons.
- Drop cargo_config: No longer required.
- Add <param name="update">true</param> to cargo_vendor service.
* Fri Jul 21 2023 Atri Bhattacharya <badshah400@gmail.com>
- Add Conflicts: ghc-wai-app-static as it installs the same binary
  called 'warp' into /usr/bin/ as this app.
* Wed Jul 12 2023 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
